@@ -94,6 +94,11 @@ class KeystoneStrategy(BaseStrategy):
             if self.creds.get("tenant") is None:
                 raise exception.MissingCredentialError(required='tenant')
 
+        # For v3 also check project is present
+        if self.creds['auth_url'].rstrip('/').endswith('v3'):
+            if self.creds.get("project") is None:
+                raise exception.MissingCredentialError(required='project')
+
     def authenticate(self):
         """Authenticate with the Keystone service.
 
@@ -113,10 +118,15 @@ class KeystoneStrategy(BaseStrategy):
             # If OS_AUTH_URL is missing a trailing slash add one
             if not auth_url.endswith('/'):
                 auth_url += '/'
+
             token_url = urlparse.urljoin(auth_url, "tokens")
             # 1. Check Keystone version
             is_v2 = auth_url.rstrip('/').endswith('v2.0')
-            if is_v2:
+            is_v3 = auth_url.rstrip('/').endswith('v3')
+            if is_v3:
+                token_url = urlparse.urljoin(auth_url, "auth/tokens")
+                self._v3_auth(token_url)
+            elif is_v2:
                 self._v2_auth(token_url)
             else:
                 self._v1_auth(token_url)
@@ -186,6 +196,52 @@ class KeystoneStrategy(BaseStrategy):
         else:
             raise Exception(_('Unexpected response: %s') % resp.status)
 
+    def _v3_auth(self, token_url):
+        creds = {
+            "auth": {
+                "identity": {
+                    "methods": ["password"],
+                    "password": {
+                        "user": {
+                            "name": self.creds['username'],
+                            "domain": {"id": self.creds['user_domain_id']},
+                            "password": self.creds['password']
+                        }
+                    }
+                },
+                "scope": {
+                    "project": {
+                        "name": self.creds['project'],
+                        "domain": {
+                            "id": self.creds['project_domain_id']
+                        }
+                    }
+                }
+            }
+        }
+
+        headers = {'Content-Type': 'application/json'}
+        req_body = jsonutils.dumps(creds)
+
+        resp, resp_body = self._do_request(
+            token_url, 'POST', headers=headers, body=req_body)
+        resp_body = jsonutils.loads(resp_body)
+
+        if resp.status == 201:
+            resp_auth = resp['x-subject-token']
+            creds_region = self.creds.get('region')
+            if self.configure_via_auth:
+                endpoint = get_endpoint(resp_body['token']['catalog'],
+                                        endpoint_region=creds_region)
+                self.management_url = endpoint
+            self.auth_token = resp_auth
+        elif resp.status == 305:
+            raise exception.RedirectException(resp['location'])
+        elif resp.status == 400:
+            raise exception.AuthBadRequest(url=token_url)
+        elif resp.status == 401:
+            raise Exception(_('Unexpected response: %s') % resp.status)
+
     def _v2_auth(self, token_url):
 
         creds = self.creds
