@@ -58,7 +58,6 @@ from glance.common import store_utils
 from glance.common import utils
 from glance import i18n
 from glance.i18n import _, _LE, _LI, _LW
-from glance.image_cache import prefetcher
 
 
 bind_opts = [
@@ -542,6 +541,9 @@ class BaseServer(object):
         self.initialize_glance_store = initialize_glance_store
         self.initialize_prefetcher = initialize_prefetcher
         if self.initialize_prefetcher:
+            # NOTE(abhishekk): Importing the prefetcher just in time to avoid
+            # import loop during initialization
+            from glance.image_cache import prefetcher  # noqa
             self.prefetcher = prefetcher.Prefetcher()
 
     def cache_images(self):
