@@ -150,6 +150,21 @@ Possible values:
 Related options:
     * ``wakeup_time``
 
+""")),
+    cfg.StrOpt('restore',
+               metavar='<IMAGE_ID>',
+               help=_("""
+Restore the image status from 'pending_delete' to 'active'.
+
+This option is used by administrator to reset the image's status from
+'pending_delete' to 'active' when the image is deleted by mistake and
+'pending delete' feature is enabled in Glance. Please make sure the
+glance-scrubber daemon is stopped before restoring the image to avoid image
+data inconsistency.
+
+Possible values:
+    * image's uuid
+
 """))
 ]
 
@@ -238,7 +253,13 @@ class ScrubDBQueue(object):
                 else:
                     uri = loc['url']
 
-                ret.append((image['id'], loc['id'], uri))
+                # if multi-store is enabled then we need to pass backend
+                # to delete the image.
+                backend = loc['metadata'].get('store')
+                if CONF.enabled_backends:
+                    ret.append((image['id'], loc['id'], uri, backend))
+                else:
+                    ret.append((image['id'], loc['id'], uri))
         return ret
 
     def has_image(self, image_id):
@@ -312,10 +333,18 @@ class Scrubber(object):
             raise exception.FailedToGetScrubberJobs()
 
         delete_jobs = {}
-        for image_id, loc_id, loc_uri in records:
-            if image_id not in delete_jobs:
-                delete_jobs[image_id] = []
-            delete_jobs[image_id].append((image_id, loc_id, loc_uri))
+        if CONF.enabled_backends:
+            for image_id, loc_id, loc_uri, backend in records:
+                if image_id not in delete_jobs:
+                    delete_jobs[image_id] = []
+                delete_jobs[image_id].append((image_id, loc_id,
+                                              loc_uri, backend))
+        else:
+            for image_id, loc_id, loc_uri in records:
+                if image_id not in delete_jobs:
+                    delete_jobs[image_id] = []
+                delete_jobs[image_id].append((image_id, loc_id, loc_uri))
+
         return delete_jobs
 
     def run(self, event=None):
@@ -332,11 +361,21 @@ class Scrubber(object):
                  {'id': image_id, 'count': len(delete_jobs)})
 
         success = True
-        for img_id, loc_id, uri in delete_jobs:
-            try:
-                self._delete_image_location_from_backend(img_id, loc_id, uri)
-            except Exception:
-                success = False
+        if CONF.enabled_backends:
+            for img_id, loc_id, uri, backend in delete_jobs:
+                try:
+                    self._delete_image_location_from_backend(img_id, loc_id,
+                                                             uri,
+                                                             backend=backend)
+                except Exception:
+                    success = False
+        else:
+            for img_id, loc_id, uri in delete_jobs:
+                try:
+                    self._delete_image_location_from_backend(img_id, loc_id,
+                                                             uri)
+                except Exception:
+                    success = False
 
         if success:
             image = db_api.get_api().image_get(self.admin_context, image_id)
@@ -349,11 +388,15 @@ class Scrubber(object):
                          "from backend. Leaving image '%s' in 'pending_delete'"
                          " status") % image_id)
 
-    def _delete_image_location_from_backend(self, image_id, loc_id, uri):
+    def _delete_image_location_from_backend(self, image_id, loc_id, uri,
+                                            backend=None):
         try:
             LOG.debug("Scrubbing image %s from a location.", image_id)
             try:
-                self.store_api.delete_from_backend(uri, self.admin_context)
+                if CONF.enabled_backends:
+                    self.store_api.delete(uri, backend, self.admin_context)
+                else:
+                    self.store_api.delete_from_backend(uri, self.admin_context)
             except store_exceptions.NotFound:
                 LOG.info(_LI("Image location for image '%s' not found in "
                              "backend; Marking image location deleted in "
@@ -371,3 +414,6 @@ class Scrubber(object):
                       {'id': image_id,
                        'exc': encodeutils.exception_to_unicode(e)})
             raise
+
+    def revert_image_status(self, image_id):
+        db_api.get_api().image_restore(self.admin_context, image_id)
