@@ -36,6 +36,7 @@ from glance.common import exception
 from glance.common import utils
 from glance.common import wsgi
 from glance import i18n
+from glance.image_cache import prefetcher
 from glance.tests import utils as test_utils
 
 
@@ -561,13 +562,25 @@ class JSONRequestDeserializerTest(test_utils.BaseTestCase):
 
 
 class ServerTest(test_utils.BaseTestCase):
-    def test_create_pool(self):
+    @mock.patch.object(prefetcher, 'Prefetcher')
+    def test_create_pool(self, mock_prefetcher):
         """Ensure the wsgi thread pool is an eventlet.greenpool.GreenPool."""
         actual = wsgi.Server(threads=1).create_pool()
         self.assertIsInstance(actual, eventlet.greenpool.GreenPool)
 
+    @mock.patch.object(prefetcher, 'Prefetcher')
     @mock.patch.object(wsgi.Server, 'configure_socket')
-    def test_http_keepalive(self, mock_configure_socket):
+    def test_reserved_stores_not_allowed(self, mock_configure_socket,
+                                         mock_prefetcher):
+        """Ensure the reserved stores are not allowed"""
+        enabled_backends = {'os_glance_file_store': 'file'}
+        self.config(enabled_backends=enabled_backends)
+        server = wsgi.Server(threads=1, initialize_glance_store=True)
+        self.assertRaises(RuntimeError, server.configure)
+
+    @mock.patch.object(prefetcher, 'Prefetcher')
+    @mock.patch.object(wsgi.Server, 'configure_socket')
+    def test_http_keepalive(self, mock_configure_socket, mock_prefetcher):
         self.config(http_keepalive=False)
         self.config(workers=0)
 
@@ -588,7 +601,8 @@ class ServerTest(test_utils.BaseTestCase):
                                                 keepalive=False,
                                                 socket_timeout=900)
 
-    def test_number_of_workers_posix(self):
+    @mock.patch.object(prefetcher, 'Prefetcher')
+    def test_number_of_workers_posix(self, mock_prefetcher):
         """Ensure the number of workers matches num cpus limited to 8."""
         if os.name == 'nt':
             raise self.skipException("Unsupported platform.")
@@ -696,7 +710,8 @@ class GetSocketTestCase(test_utils.BaseTestCase):
         wsgi.CONF.ca_file = '/etc/ssl/ca_cert'
         wsgi.CONF.tcp_keepidle = 600
 
-    def test_correct_configure_socket(self):
+    @mock.patch.object(prefetcher, 'Prefetcher')
+    def test_correct_configure_socket(self, mock_prefetcher):
         mock_socket = mock.Mock()
         self.useFixture(fixtures.MonkeyPatch(
             'glance.common.wsgi.ssl.wrap_socket',
