@@ -12,6 +12,7 @@
 #    WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied. See the
 #    License for the specific language governing permissions and limitations
 #    under the License.
+import copy
 import uuid
 
 import mock
@@ -42,7 +43,7 @@ class FakeImage(object):
     locations = [{'url': 'file:///not/a/path', 'metadata': {}}]
     tags = set([])
 
-    def set_data(self, data, size=None):
+    def set_data(self, data, size=None, backend=None):
         self.size = 0
         for d in data:
             self.size += len(d)
@@ -52,6 +53,7 @@ class FakeImage(object):
 
 
 class TestImageQuota(test_utils.BaseTestCase):
+
     def setUp(self):
         super(TestImageQuota, self).setUp()
 
@@ -283,8 +285,8 @@ class TestImageQuota(test_utils.BaseTestCase):
         image = glance.quota.ImageProxy(base_image, context, db_api, store)
         self.assertIsNone(image.size)
 
-        self.stubs.Set(store_api, 'get_size_from_backend',
-                       unit_test_utils.fake_get_size_from_backend)
+        self.mock_object(store_api, 'get_size_from_backend',
+                         unit_test_utils.fake_get_size_from_backend)
         image.locations.append({'url': 'file:///fake.img.tar.gz',
                                 'metadata': {}})
         self.assertIn({'url': 'file:///fake.img.tar.gz', 'metadata': {}},
@@ -300,8 +302,8 @@ class TestImageQuota(test_utils.BaseTestCase):
         image = glance.quota.ImageProxy(base_image, context, db_api, store)
         self.assertIsNone(image.size)
 
-        self.stubs.Set(store_api, 'get_size_from_backend',
-                       unit_test_utils.fake_get_size_from_backend)
+        self.mock_object(store_api, 'get_size_from_backend',
+                         unit_test_utils.fake_get_size_from_backend)
         image.locations.insert(0,
                                {'url': 'file:///fake.img.tar.gz',
                                 'metadata': {}})
@@ -318,8 +320,8 @@ class TestImageQuota(test_utils.BaseTestCase):
         image = glance.quota.ImageProxy(base_image, context, db_api, store)
         self.assertIsNone(image.size)
 
-        self.stubs.Set(store_api, 'get_size_from_backend',
-                       unit_test_utils.fake_get_size_from_backend)
+        self.mock_object(store_api, 'get_size_from_backend',
+                         unit_test_utils.fake_get_size_from_backend)
         image.locations = [{'url': 'file:///fake.img.tar.gz', 'metadata': {}}]
         self.assertEqual([{'url': 'file:///fake.img.tar.gz', 'metadata': {}}],
                          image.locations)
@@ -334,14 +336,15 @@ class TestImageQuota(test_utils.BaseTestCase):
         image = glance.quota.ImageProxy(base_image, context, db_api, store)
         self.assertIsNone(image.size)
 
-        self.stubs.Set(store_api, 'get_size_from_backend',
-                       unit_test_utils.fake_get_size_from_backend)
+        self.mock_object(store_api, 'get_size_from_backend',
+                         unit_test_utils.fake_get_size_from_backend)
         image.locations += [{'url': 'file:///fake.img.tar.gz', 'metadata': {}}]
         self.assertIn({'url': 'file:///fake.img.tar.gz', 'metadata': {}},
                       image.locations)
 
 
 class TestImagePropertyQuotas(test_utils.BaseTestCase):
+
     def setUp(self):
         super(TestImagePropertyQuotas, self).setUp()
         self.base_image = FakeImage()
@@ -485,6 +488,7 @@ class TestImagePropertyQuotas(test_utils.BaseTestCase):
 
 
 class TestImageTagQuotas(test_utils.BaseTestCase):
+
     def setUp(self):
         super(TestImageTagQuotas, self).setUp()
         self.base_image = mock.Mock()
@@ -549,6 +553,7 @@ class TestImageTagQuotas(test_utils.BaseTestCase):
 
 
 class TestQuotaImageTagsProxy(test_utils.BaseTestCase):
+
     def setUp(self):
         super(TestQuotaImageTagsProxy, self).setUp()
 
@@ -592,8 +597,28 @@ class TestQuotaImageTagsProxy(test_utils.BaseTestCase):
             items.remove(item)
         self.assertEqual(0, len(items))
 
+    def test_tags_attr_no_loop(self):
+        proxy = glance.quota.QuotaImageTagsProxy(None)
+        self.assertEqual(set([]), proxy.tags)
+
+    def test_tags_deepcopy(self):
+        proxy = glance.quota.QuotaImageTagsProxy(set(['a', 'b']))
+        proxy_copy = copy.deepcopy(proxy)
+        self.assertEqual(set(['a', 'b']), proxy_copy.tags)
+        self.assertIn('a', proxy_copy)
+        # remove is a found via __getattr__
+        proxy_copy.remove('a')
+        self.assertNotIn('a', proxy_copy)
+
+    def test_tags_delete(self):
+        proxy = glance.quota.QuotaImageTagsProxy(set(['a', 'b']))
+        self.assertEqual(set(['a', 'b']), proxy.tags)
+        del proxy.tags
+        self.assertIsNone(proxy.tags)
+
 
 class TestImageMemberQuotas(test_utils.BaseTestCase):
+
     def setUp(self):
         super(TestImageMemberQuotas, self).setUp()
         db_api = unit_test_utils.FakeDB()
@@ -631,6 +656,7 @@ class TestImageMemberQuotas(test_utils.BaseTestCase):
 
 
 class TestImageLocationQuotas(test_utils.BaseTestCase):
+
     def setUp(self):
         super(TestImageLocationQuotas, self).setUp()
         self.base_image = mock.Mock()
